==> dif-database-repository-2.7.1-sources.jar: pt/digitalis/dif/dem/managers/impl/model/data/DataIntegrationSetFieldAttributes.java <==
package pt.digitalis.dif.dem.managers.impl.model.data;

import pt.digitalis.utils.common.AttributeDefinition;
import pt.digitalis.dif.model.utils.AbstractBeanAttributesDefinition;

import java.sql.Timestamp;
import java.sql.Blob;
import java.util.Date;
import java.math.BigDecimal;

import java.util.Arrays;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import pt.digitalis.utils.common.collections.CaseInsensitiveHashMap;

import org.hibernate.Session;


/**
 *  Field definitions for data object {@link DataIntegrationSet}
 *
 * NOTE: This file is auto generated and will be overwritten in a future file generation.
 */
public class DataIntegrationSetFieldAttributes extends AbstractBeanAttributesDefinition{

    /** configId (Database column: CONFIG_ID) */
    static public AttributeDefinition configId =
        new AttributeDefinition("configId")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("DATA_INTEGRATION_SET")
                .setDatabaseId("CONFIG_ID")
                .setMandatory(true)
                .setMaxSize(255)
                .setType(String.class);

    /** creationDate (Database column: CREATION_DATE) */
    static public AttributeDefinition creationDate =
        new AttributeDefinition("creationDate")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("DATA_INTEGRATION_SET")
                .setDatabaseId("CREATION_DATE")
                .setMandatory(true)
                .setMaxSize(7)
                .setType(Timestamp.class);

    /** id (Database column: ID) */
    static public AttributeDefinition id =
        new AttributeDefinition("id")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("DATA_INTEGRATION_SET")
                .setDatabaseId("ID")
                .setMandatory(true)
                .setMaxSize(255)
                .setType(Long.class);

    /** processId (Database column: PROCESS_ID) */
    static public AttributeDefinition processId =
        new AttributeDefinition("processId")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("DATA_INTEGRATION_SET")
                .setDatabaseId("PROCESS_ID")
                .setMandatory(true)
                .setMaxSize(255)
                .setType(String.class);

    /**
    * Create definitions map map.
    *
    * @return the map
    */
    @Override protected CaseInsensitiveHashMap<AttributeDefinition> createDefinitionsMap(){
        CaseInsensitiveHashMap<AttributeDefinition> map = new CaseInsensitiveHashMap<AttributeDefinition>();
        map.put(configId.getName(),configId);
        map.put(creationDate.getName(),creationDate);
        map.put(id.getName(),id);
        map.put(processId.getName(),processId);

        return map;
    }
}

==> dif-database-repository-2.7.3-5-sources.jar: pt/digitalis/dif/dem/managers/impl/model/data/DataIntegrationSetFieldAttributes.java <==
package pt.digitalis.dif.dem.managers.impl.model.data;

import pt.digitalis.utils.common.AttributeDefinition;
import pt.digitalis.dif.model.utils.AbstractBeanAttributesDefinition;

import java.sql.Timestamp;
import java.sql.Blob;
import java.util.Date;
import java.math.BigDecimal;

import java.util.Arrays;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import pt.digitalis.utils.common.collections.CaseInsensitiveHashMap;

import org.hibernate.Session;


/**
 *  Field definitions for data object {@link DataIntegrationSet}
 *
 * NOTE: This file is auto generated and will be overwritten in a future file generation.
 */
public class DataIntegrationSetFieldAttributes extends AbstractBeanAttributesDefinition{

    /** configId (Database column: CONFIG_ID) */
    static public AttributeDefinition configId =
        new AttributeDefinition("configId")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("DATA_INTEGRATION_SET")
                .setDatabaseId("CONFIG_ID")
                .setMandatory(true)
                .setMaxSize(255)
                .setType(String.class);

    /** creationDate (Database column: CREATION_DATE) */
    static public AttributeDefinition creationDate =
        new AttributeDefinition("creationDate")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("DATA_INTEGRATION_SET")
                .setDatabaseId("CREATION_DATE")
                .setMandatory(true)
                .setMaxSize(7)
                .setType(Timestamp.class);

    /** id (Database column: ID) */
    static public AttributeDefinition id =
        new AttributeDefinition("id")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("DATA_INTEGRATION_SET")
                .setDatabaseId("ID")
                .setMandatory(true)
                .setMaxSize(10)
                .setType(Long.class);

    /** processId (Database column: PROCESS_ID) */
    static public AttributeDefinition processId =
        new AttributeDefinition("processId")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("DATA_INTEGRATION_SET")
                .setDatabaseId("PROCESS_ID")
                .setMandatory(true)
                .setMaxSize(255)
                .setType(String.class);

    /**
     * Gets description field.
     *
     * @return the description field
     */
    public static String getDescriptionField()
    {
        return null;
    }

    /**
    * Create definitions map map.
    *
    * @return the map
    */
    @Override protected CaseInsensitiveHashMap<AttributeDefinition> createDefinitionsMap(){
        CaseInsensitiveHashMap<AttributeDefinition> map = new CaseInsensitiveHashMap<AttributeDefinition>();
        map.put(configId.getName(),configId);
        map.put(creationDate.getName(),creationDate);
        map.put(id.getName(),id);
        map.put(processId.getName(),processId);

        return map;
    }
}
